@@ -13,5 +13,5 @@ def checkAllTypes(owner: Owner) -> None:
     """
     Checks all types that are within the Owner object.
     """
-    if type(owner.name) != str:
+    if not isinstance(owner.name, str):
         raise InvalidOwnerFormatException("name must be type 'str'.")
