@@ -2,6 +2,7 @@ import unittest
 
 from leeger.calculator.all_time_calculator import AWALAllTimeCalculator
 from leeger.enum.MatchupType import MatchupType
+from leeger.model.league import YearSettings
 from leeger.model.league.League import League
 from leeger.model.league.Matchup import Matchup
 from leeger.model.league.Week import Week
@@ -48,6 +49,43 @@ class TestAWALAllTimeCalculator(unittest.TestCase):
         self.assertEqual(Deci("2.1"), response[owners[4].id])
         self.assertEqual(Deci("3"), response[owners[5].id])
 
+    def test_getAWAL_leagueMedianGamesIsOn_addsLeagueMedianWinsToAWAL(self):
+        owners, teamsA = getNDefaultOwnersAndTeams(6)
+        teamsB = getTeamsFromOwners(owners)
+        teamsC = getTeamsFromOwners(owners)
+        yearSettings = YearSettings(leagueMedianGames=True)
+
+        matchup1_a = Matchup(teamAId=teamsA[0].id, teamBId=teamsA[1].id, teamAScore=1, teamBScore=2)
+        matchup2_a = Matchup(teamAId=teamsA[2].id, teamBId=teamsA[3].id, teamAScore=3, teamBScore=4)
+        matchup3_a = Matchup(teamAId=teamsA[4].id, teamBId=teamsA[5].id, teamAScore=4, teamBScore=5)
+        week1_a = Week(weekNumber=1, matchups=[matchup1_a, matchup2_a, matchup3_a])
+        yearA = Year(yearNumber=2000, teams=teamsA, weeks=[week1_a], yearSettings=yearSettings)
+
+        matchup1_b = Matchup(teamAId=teamsB[0].id, teamBId=teamsB[1].id, teamAScore=1, teamBScore=2)
+        matchup2_b = Matchup(teamAId=teamsB[2].id, teamBId=teamsB[3].id, teamAScore=3, teamBScore=4)
+        matchup3_b = Matchup(teamAId=teamsB[4].id, teamBId=teamsB[5].id, teamAScore=4, teamBScore=5)
+        week1_b = Week(weekNumber=1, matchups=[matchup1_b, matchup2_b, matchup3_b])
+        yearB = Year(yearNumber=2001, teams=teamsB, weeks=[week1_b], yearSettings=yearSettings)
+
+        matchup1_c = Matchup(teamAId=teamsC[0].id, teamBId=teamsC[1].id, teamAScore=1, teamBScore=2)
+        matchup2_c = Matchup(teamAId=teamsC[2].id, teamBId=teamsC[3].id, teamAScore=3, teamBScore=4)
+        matchup3_c = Matchup(teamAId=teamsC[4].id, teamBId=teamsC[5].id, teamAScore=4, teamBScore=5)
+        week1_c = Week(weekNumber=1, matchups=[matchup1_c, matchup2_c, matchup3_c])
+        yearC = Year(yearNumber=2002, teams=teamsC, weeks=[week1_c], yearSettings=yearSettings)
+
+        league = League(name="TEST", owners=owners, years=[yearA, yearB, yearC])
+
+        response = AWALAllTimeCalculator.getAWAL(league)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(6, len(response.keys()))
+        self.assertEqual(Deci("0"), response[owners[0].id])
+        self.assertEqual(Deci("0.6"), response[owners[1].id])
+        self.assertEqual(Deci("1.2"), response[owners[2].id])
+        self.assertEqual(Deci("5.1"), response[owners[3].id])
+        self.assertEqual(Deci("5.1"), response[owners[4].id])
+        self.assertEqual(Deci("6"), response[owners[5].id])
+
     def test_getAWAL_noneIfNoGamesPlayed(self):
         owners, teamsA = getNDefaultOwnersAndTeams(3)
 
@@ -341,6 +379,43 @@ class TestAWALAllTimeCalculator(unittest.TestCase):
         self.assertEqual(Deci("0.7"), response[owners[4].id])
         self.assertEqual(Deci("1"), response[owners[5].id])
 
+    def test_getAWALPerGame_leagueMedianGamesIsOn(self):
+        owners, teamsA = getNDefaultOwnersAndTeams(6)
+        teamsB = getTeamsFromOwners(owners)
+        teamsC = getTeamsFromOwners(owners)
+        yearSettings = YearSettings(leagueMedianGames=True)
+
+        matchup1_a = Matchup(teamAId=teamsA[0].id, teamBId=teamsA[1].id, teamAScore=1, teamBScore=2)
+        matchup2_a = Matchup(teamAId=teamsA[2].id, teamBId=teamsA[3].id, teamAScore=3, teamBScore=4)
+        matchup3_a = Matchup(teamAId=teamsA[4].id, teamBId=teamsA[5].id, teamAScore=4, teamBScore=5)
+        week1_a = Week(weekNumber=1, matchups=[matchup1_a, matchup2_a, matchup3_a])
+        yearA = Year(yearNumber=2000, teams=teamsA, weeks=[week1_a], yearSettings=yearSettings)
+
+        matchup1_b = Matchup(teamAId=teamsB[0].id, teamBId=teamsB[1].id, teamAScore=1, teamBScore=2)
+        matchup2_b = Matchup(teamAId=teamsB[2].id, teamBId=teamsB[3].id, teamAScore=3, teamBScore=4)
+        matchup3_b = Matchup(teamAId=teamsB[4].id, teamBId=teamsB[5].id, teamAScore=4, teamBScore=5)
+        week1_b = Week(weekNumber=1, matchups=[matchup1_b, matchup2_b, matchup3_b])
+        yearB = Year(yearNumber=2001, teams=teamsB, weeks=[week1_b], yearSettings=yearSettings)
+
+        matchup1_c = Matchup(teamAId=teamsC[0].id, teamBId=teamsC[1].id, teamAScore=1, teamBScore=2)
+        matchup2_c = Matchup(teamAId=teamsC[2].id, teamBId=teamsC[3].id, teamAScore=3, teamBScore=4)
+        matchup3_c = Matchup(teamAId=teamsC[4].id, teamBId=teamsC[5].id, teamAScore=4, teamBScore=5)
+        week1_c = Week(weekNumber=1, matchups=[matchup1_c, matchup2_c, matchup3_c])
+        yearC = Year(yearNumber=2002, teams=teamsC, weeks=[week1_c], yearSettings=yearSettings)
+
+        league = League(name="TEST", owners=owners, years=[yearA, yearB, yearC])
+
+        response = AWALAllTimeCalculator.getAWALPerGame(league)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(6, len(response.keys()))
+        self.assertEqual(Deci("0"), response[owners[0].id])
+        self.assertEqual(Deci("0.1"), response[owners[1].id])
+        self.assertEqual(Deci("0.2"), response[owners[2].id])
+        self.assertEqual(Deci("0.85"), response[owners[3].id])
+        self.assertEqual(Deci("0.85"), response[owners[4].id])
+        self.assertEqual(Deci("1"), response[owners[5].id])
+
     def test_getAWALPerGame_noneIfNoGamesPlayed(self):
         owners, teamsA = getNDefaultOwnersAndTeams(3)
 
@@ -635,6 +710,44 @@ class TestAWALAllTimeCalculator(unittest.TestCase):
         self.assertEqual(Deci("3"), response[owners[4].id])
         self.assertEqual(Deci("2.1"), response[owners[5].id])
 
+    def test_getOpponentAWAL_leagueMedianGamesIsOn_countsLeagueMedianGames(self):
+        owners, teamsA = getNDefaultOwnersAndTeams(6)
+        teamsB = getTeamsFromOwners(owners)
+        teamsC = getTeamsFromOwners(owners)
+        yearSettings = YearSettings(leagueMedianGames=True)
+
+        matchup1_a = Matchup(teamAId=teamsA[0].id, teamBId=teamsA[1].id, teamAScore=1, teamBScore=2)
+        matchup2_a = Matchup(teamAId=teamsA[2].id, teamBId=teamsA[3].id, teamAScore=3, teamBScore=4)
+        matchup3_a = Matchup(teamAId=teamsA[4].id, teamBId=teamsA[5].id, teamAScore=4, teamBScore=5)
+        week1_a = Week(weekNumber=1, matchups=[matchup1_a, matchup2_a, matchup3_a])
+        yearA = Year(yearNumber=2000, teams=teamsA, weeks=[week1_a], yearSettings=yearSettings)
+
+        matchup1_b = Matchup(teamAId=teamsB[0].id, teamBId=teamsB[1].id, teamAScore=1, teamBScore=2)
+        matchup2_b = Matchup(teamAId=teamsB[2].id, teamBId=teamsB[3].id, teamAScore=3, teamBScore=4)
+        matchup3_b = Matchup(teamAId=teamsB[4].id, teamBId=teamsB[5].id, teamAScore=4, teamBScore=5)
+        week1_b = Week(weekNumber=1, matchups=[matchup1_b, matchup2_b, matchup3_b])
+        yearB = Year(yearNumber=2001, teams=teamsB, weeks=[week1_b], yearSettings=yearSettings)
+
+        matchup1_c = Matchup(teamAId=teamsC[0].id, teamBId=teamsC[1].id, teamAScore=1, teamBScore=2)
+        matchup2_c = Matchup(teamAId=teamsC[2].id, teamBId=teamsC[3].id, teamAScore=3, teamBScore=4)
+        matchup3_c = Matchup(teamAId=teamsC[4].id, teamBId=teamsC[5].id, teamAScore=4, teamBScore=5)
+        week1_c = Week(weekNumber=1, matchups=[matchup1_c, matchup2_c, matchup3_c])
+        yearC = Year(yearNumber=2002, teams=teamsC, weeks=[week1_c], yearSettings=yearSettings)
+
+        league = League(name="TEST", owners=owners, years=[yearA, yearB, yearC])
+
+        response = AWALAllTimeCalculator.getOpponentAWAL(league)
+        test = AWALAllTimeCalculator.getAWAL(league)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(6, len(response.keys()))
+        self.assertEqual(Deci("0.6"), response[owners[0].id])
+        self.assertEqual(Deci("0"), response[owners[1].id])
+        self.assertEqual(Deci("5.1"), response[owners[2].id])
+        self.assertEqual(Deci("1.2"), response[owners[3].id])
+        self.assertEqual(Deci("6"), response[owners[4].id])
+        self.assertEqual(Deci("5.1"), response[owners[5].id])
+
     def test_getOpponentAWAL_noneIfNoGamesPlayed(self):
         owners, teamsA = getNDefaultOwnersAndTeams(3)
 
@@ -929,6 +1042,43 @@ class TestAWALAllTimeCalculator(unittest.TestCase):
         self.assertEqual(Deci("1"), response[owners[4].id])
         self.assertEqual(Deci("0.7"), response[owners[5].id])
 
+    def test_getOpponentAWALPerGame_leagueMedianGamesIsOn(self):
+        owners, teamsA = getNDefaultOwnersAndTeams(6)
+        teamsB = getTeamsFromOwners(owners)
+        teamsC = getTeamsFromOwners(owners)
+        yearSettings = YearSettings(leagueMedianGames=True)
+
+        matchup1_a = Matchup(teamAId=teamsA[0].id, teamBId=teamsA[1].id, teamAScore=1, teamBScore=2)
+        matchup2_a = Matchup(teamAId=teamsA[2].id, teamBId=teamsA[3].id, teamAScore=3, teamBScore=4)
+        matchup3_a = Matchup(teamAId=teamsA[4].id, teamBId=teamsA[5].id, teamAScore=4, teamBScore=5)
+        week1_a = Week(weekNumber=1, matchups=[matchup1_a, matchup2_a, matchup3_a])
+        yearA = Year(yearNumber=2000, teams=teamsA, weeks=[week1_a], yearSettings=yearSettings)
+
+        matchup1_b = Matchup(teamAId=teamsB[0].id, teamBId=teamsB[1].id, teamAScore=1, teamBScore=2)
+        matchup2_b = Matchup(teamAId=teamsB[2].id, teamBId=teamsB[3].id, teamAScore=3, teamBScore=4)
+        matchup3_b = Matchup(teamAId=teamsB[4].id, teamBId=teamsB[5].id, teamAScore=4, teamBScore=5)
+        week1_b = Week(weekNumber=1, matchups=[matchup1_b, matchup2_b, matchup3_b])
+        yearB = Year(yearNumber=2001, teams=teamsB, weeks=[week1_b], yearSettings=yearSettings)
+
+        matchup1_c = Matchup(teamAId=teamsC[0].id, teamBId=teamsC[1].id, teamAScore=1, teamBScore=2)
+        matchup2_c = Matchup(teamAId=teamsC[2].id, teamBId=teamsC[3].id, teamAScore=3, teamBScore=4)
+        matchup3_c = Matchup(teamAId=teamsC[4].id, teamBId=teamsC[5].id, teamAScore=4, teamBScore=5)
+        week1_c = Week(weekNumber=1, matchups=[matchup1_c, matchup2_c, matchup3_c])
+        yearC = Year(yearNumber=2002, teams=teamsC, weeks=[week1_c], yearSettings=yearSettings)
+
+        league = League(name="TEST", owners=owners, years=[yearA, yearB, yearC])
+
+        response = AWALAllTimeCalculator.getOpponentAWALPerGame(league)
+
+        self.assertIsInstance(response, dict)
+        self.assertEqual(6, len(response.keys()))
+        self.assertEqual(Deci("0.1"), response[owners[0].id])
+        self.assertEqual(Deci("0"), response[owners[1].id])
+        self.assertEqual(Deci("0.85"), response[owners[2].id])
+        self.assertEqual(Deci("0.2"), response[owners[3].id])
+        self.assertEqual(Deci("1"), response[owners[4].id])
+        self.assertEqual(Deci("0.85"), response[owners[5].id])
+
     def test_getOpponentAWALPerGame_noneIfNoGamesPlayed(self):
         owners, teamsA = getNDefaultOwnersAndTeams(3)
 
